package com.srs.teacher.service.impl;

import java.util.List;

import com.srs.teacher.domain.SysPerformanceActive;
import org.springframework.beans.factory.annotation.Autowired;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import com.srs.teacher.mapper.SysPerformanceServingMapper;
import com.srs.teacher.domain.SysPerformanceServing;
import com.srs.teacher.service.ISysPerformanceServingService;

/**
 * 综合绩效-担任职务Service业务层处理
 *
 * @author srs
 * @date 2024-06-17
 */
@Service
public class SysPerformanceServingServiceImpl extends ServiceImpl<SysPerformanceServingMapper,SysPerformanceServing> implements ISysPerformanceServingService {
    @Autowired
    private SysPerformanceServingMapper sysPerformanceServingMapper;

    /**
     * 查询综合绩效-担任职务
     *
     * @param id 综合绩效-担任职务主键
     * @return 综合绩效-担任职务
     */
    @Override
    public SysPerformanceServing selectSysPerformanceServingById(Long id) {
        return sysPerformanceServingMapper.selectSysPerformanceServingById(id);
    }

    @Override
    public SysPerformanceServing selectSysPerformanceServingByFdyName(String fdName, String years) {
        return sysPerformanceServingMapper.selectSysPerformanceServingByFdyName(fdName, years);
    }

    /**
     * 查询综合绩效-担任职务列表
     *
     * @param sysPerformanceServing 综合绩效-担任职务
     * @return 综合绩效-担任职务
     */
    @Override
    public List<SysPerformanceServing> selectSysPerformanceServingList(SysPerformanceServing sysPerformanceServing) {
        return sysPerformanceServingMapper.selectSysPerformanceServingList(sysPerformanceServing);
    }

    /**
     * 新增综合绩效-担任职务
     *
     * @param sysPerformanceServing 综合绩效-担任职务
     * @return 结果
     */
    @Override
    public int insertSysPerformanceServing(SysPerformanceServing sysPerformanceServing) {
            return sysPerformanceServingMapper.insertSysPerformanceServing(sysPerformanceServing);
    }

    /**
     * 修改综合绩效-担任职务
     *
     * @param sysPerformanceServing 综合绩效-担任职务
     * @return 结果
     */
    @Override
    public int updateSysPerformanceServing(SysPerformanceServing sysPerformanceServing) {
        return sysPerformanceServingMapper.updateSysPerformanceServing(sysPerformanceServing);
    }

    /**
     * 批量删除综合绩效-担任职务
     *
     * @param ids 需要删除的综合绩效-担任职务主键
     * @return 结果
     */
    @Override
    public int deleteSysPerformanceServingByIds(Long[] ids) {
        return sysPerformanceServingMapper.deleteSysPerformanceServingByIds(ids);
    }

    /**
     * 删除综合绩效-担任职务信息
     *
     * @param id 综合绩效-担任职务主键
     * @return 结果
     */
    @Override
    public int deleteSysPerformanceServingById(Long id) {
        return sysPerformanceServingMapper.deleteSysPerformanceServingById(id);
    }
}
